#
# spec file for package python-pamqp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-pamqp
Version:        3.2.1
Release:        1.5
Summary:        Pure-python AMQP 0-9-1 frame encoder and decoder
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/gmr/pamqp
Source:         https://github.com/gmr/pamqp/archive/%{version}.tar.gz#/pamqp-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
pamqp is a pure-python AMQP 0-9-1 frame encoder and decoder.

pamqp is not a end-user client library for talking to RabbitMQ but
rather is used by client libraries for marshaling and unmarshaling
AMQP frames.

AMQP class/method command class mappings can be found in the
pamqp.specification module while actual frame encoding and
encoding should be run through the pamqp.frame module.

%prep
%setup -q -n pamqp-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/pamqp*

%check
# DemarshalingTests.test_basic_properties fails in v3.0.1 due to failing datetime value comparison
%pytest -k 'not (DemarshalingTests and test_basic_properties)' tests/*

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.2.1
  Fix line length issue in comment
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.2.0 (2022-06-27)
  * Allow long-str to fall back to bytes in case of UnicodeDecodeError (AMQP 1.0 interop) (#40 - dmaone)
  * DOMAIN_REGEX enhanced to fulfill tag uri scheme for exchange and queue names. (#42 - deschmih)
- Update to 3.1.0 (2022-01-10)
  * Add implicit UTC timezone behavior to the AMQP Basic.Properties timestamp value. (#37 - RemiCardona)
  * Add support for short-short-int and short-short-uint. (#33 - michal800106)
* Tue Feb 23 2021 John Vandenberg <jayvdb@gmail.com>
- Disabled Python 2 builds
- Update to v3.0.1
  * See https://github.com/gmr/pamqp/blob/master/docs/changelog.rst
* Tue Jun  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- replace nose with pytest
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Apr 26 2019 pgajdos@suse.com
- do not require unittest2 for testing with python3
* Fri Apr 26 2019 pgajdos@suse.com
- version update to 2.3.0
  - Add :py:func:`pamqp.encode.support_deprecated_rabbitmq` function
    to limit data types available when encoding field-tables for older
    RabbitMQ versions.
  - Change :py:meth:`pamqp.encode.timestamp` to allow for numeric/epoch
    timestamps (#14 - `mosquito <https://github.com/mosquito>`_)
  - Change :py:meth:`pamqp.frame.frame_parts` to a public method
    (#15 - `mosquito <https://github.com/mosquito>`_)
  - Cleanup of code to pass configured flake8 tests
  - Add support for 8-bit unsigned integer values in
    :py:meth:`pamqp.encode.table_integer`
* Fri Mar 29 2019 pgajdos@suse.com
- version update to 2.1.0
  * Change raising a DeprecationWarning exception to using
    warnings.warn for deprecated AMQP methods
* Fri Sep 21 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 2.0.0:
  * Small bugfixes only, support for py3.4+ and 2.7+ only
- Drop upstream merged patch:
  * 776d086553bd04630cb1d9e2f429c7bf05b1ca23.patch
* Wed Sep 12 2018 mcepl@suse.com
- Add 776d086553bd04630cb1d9e2f429c7bf05b1ca23.patch fixing tests
  on 32bit archs. See https://github.com/gmr/pamqp/issues/11
* Wed Aug 29 2018 tchvatal@suse.com
- Switch to github tarball to get tests
- Run tests
* Thu Dec  7 2017 sean.marlow@suse.com
- Initial release v1.6.1
